@@ -127,7 +127,6 @@
 
 (defun thf-fail (msg s)
 ;  (format t "*** WARNING: ~d Skipping ~S~%" msg s)
-;  (progn (setq *s* s) (break)) ; delete me
   (throw 'done 'thf-fail))
 
 (defun ar (a b)
@@ -191,7 +190,7 @@
 	(let ((abh (gethash ab *aph*)))
 	  (or abh
 	      (let ((apab (cons (cons 'AP ab) (cddr a))))
-		(when *debug* (get-partial-ctx apab)) ; delete me
+;		(when *debug* (get-partial-ctx apab)) ; uncomment to debug
 		(setf (gethash ab *aph*) apab)
 		apab))))
     (thf-fail "Not well-typed" (cons a b))))
@@ -486,8 +485,8 @@
 	 (Xsub (gethash X-sub *evarh*)))
     (or Xsub
 	(let ((Xsub (cons (cons 'EVAR X-sub) (get X 'tp))))
-	  (when *debug* (unless (equal (mapcar #'cdr sub) (get X 'ctx)) (thf-fail "Not well-typed" Xsub)))
-	  (when *debug* (get-partial-ctx Xsub)) ; delete me
+;	  (when *debug* (unless (equal (mapcar #'cdr sub) (get X 'ctx)) (thf-fail "Not well-typed" Xsub)))
+;	  (when *debug* (get-partial-ctx Xsub)) ; uncomment to debug
 	  (setf (gethash X-sub *evarh*) Xsub)
 	  Xsub))))
 
@@ -724,8 +723,15 @@
   (when *verbose* (format t "Calling minisat..."))
   (let* ((p (sb-ext:run-program *minisat-binary* nil :wait nil :input :stream))
 	 (ps (sb-ext:process-input p)))
-    (write-string *clauses* ps)
-    (close ps)
+    (handler-case
+     (progn
+       (write-string *clauses* ps)
+       (close ps))
+     (error (x) 
+	    (unless *slave*
+	      (format t "% SZS status Error :~%Problem writing to minisat ~d~%" *minisat-binary*)
+	      )
+	    (sb-ext:quit :unix-status 1)))
     (handler-case
      (with-timeout *minisat-timeout*
        (sb-ext:process-wait p t)
@@ -802,8 +808,8 @@
       (append-clause (format nil "~d ~d"
 			     (get-literal empty-s)
 			     (get-literal s-eps-s)))
-      (agenda-en (list 'DELAY *choice-empty-delay* (list 'PROP (myneg empty-s))))
-      (agenda-en (list 'DELAY *choice-in-delay* (list 'PROP (myneg s-eps-s))))
+      (agenda-en (list 'DELAY *choice-empty-delay* (list 'PROP empty-s))) ; was a bug in <= 1.1, negated this, fixed - Chad, Jan 15, 2010
+      (agenda-en (list 'DELAY *choice-in-delay* (list 'PROP s-eps-s))) ; was a bug in <= 1.1, negated this, fixed - Chad, Jan 15, 2010
       )))
 
 (defun new-instantiation (a m)
@@ -1278,7 +1284,7 @@
   (let ((ag nil)
 	(i 0))
     (loop while (setq ag (agenda-de)) do
-	  (when *debug* (setq *ag* ag)) ; delete me
+;	  (when *debug* (setq *ag* ag)) ; uncomment to debug
 	  (incf i)
 	  (when (= i *call-period*) ; call minisat periodically
 	    (when *debug* (format t "Calling Minisat~%"))
@@ -1652,7 +1658,11 @@
 					 (agenda-push (list 'DELAY *imitate-defn-delay* (list 'ENUM-AP (get c 'defh) ectx (cdr evars) m tp))))
 				     (if (get c 'consth)
 					 (agenda-push (list 'DELAY *imitate-delay* (list 'ENUM-AP (get c 'consth) ectx (cdr evars) m tp)))
-				       (progn (setq *c* c) (break)))))))))) ; delete me
+				       (progn
+;					 (setq *c* c) (break) ; uncomment to debug
+					 nil
+					 )
+				       ))))))))
 					; otherwise done...m should be a term of the right type
 		     (progn
 		       (when *debug*
@@ -1742,24 +1752,23 @@
 	(if (and (consp dom) (eq (cdr dom) *O*))
 	    (let ((tp (car dom))
 		  (body (lam-body (ap-a m))))
-	      (if (and (neg-p body) (and-p (ap-a body)))
-		  (let ((l (bin-l (ap-a body))) ; ~ !:<tp>.~1 0
-			(r (bin-r (ap-a body)))) ; ~ 0 (<name> 0)
-		    (if (and (neg-p r)
+	      (if (or-p body)
+		  ; I suppose I could also check for the symmetric version...but I'm not for now.
+		  (let ((l (bin-l body)) ; !:<tp>.~1 0
+			(r (bin-r body))) ; 0 (<name> 0)
+		    (if (and (ap-p r)
 			     (ap-p (ap-a r))
-			     (ap-p (ap-a (ap-a r)))
-			     (equal (car (ap-f (ap-a r))) 0)
-			     (equal (car (ap-a (ap-a (ap-a r)))) 0)
-			     (symbolp (car (ap-f (ap-a (ap-a r))))) ; this is what to return
-			     (neg-p l)
-			     (all-p (ap-a l))
-			     (lam-p (ap-a (ap-a l)))
-			     (eq (lam-dom (ap-a (ap-a l))) tp)
-			     (neg-p (lam-body (ap-a (ap-a l))))
-			     (ap-p (ap-a (lam-body (ap-a (ap-a l)))))
-			     (equal (car (ap-f (ap-a (lam-body (ap-a (ap-a l)))))) 1)
-			     (equal (car (ap-a (ap-a (lam-body (ap-a (ap-a l)))))) 0))
-			(ap-f (ap-a (ap-a r)))
+			     (equal (car (ap-f r)) 0)
+			     (equal (car (ap-a (ap-a r))) 0)
+			     (symbolp (car (ap-f (ap-a r)))) ; this is what to return
+			     (all-p l)
+			     (lam-p (ap-a l))
+			     (eq (lam-dom (ap-a l)) tp)
+			     (neg-p (lam-body (ap-a l)))
+			     (ap-p (ap-a (lam-body (ap-a l))))
+			     (equal (car (ap-f (ap-a (lam-body (ap-a l))))) 1)
+			     (equal (car (ap-a (ap-a (lam-body (ap-a l))))) 0))
+			(ap-f (ap-a r))
 		      nil))
 		nil))
 	  nil))
@@ -1864,38 +1873,46 @@
       (if (eq foo 'inconsistent)
 	  (let ((r 20))
 	    (if *conjecture-given*
-		(format t "+- SUCCESS! Theorem Proven~%")
+		(format t "% SZS status Theorem~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
 	      (progn
-		(format t "+- SUCCESS! Unsatisfiable~%")
+		(format t "% SZS status Unsatisfiable~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
 		(setq r 25)))
 	    (when *print-final-proof-info*
-	      (format t "SZS output start Proof~%")
+	      (format t "% SZS output start Proof~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
 	      (format t "Clauses:~%")
 	      (write-string *clauses*)
 	      (format t "Atoms:~%")
 	      (print-atom-atlas)
-	      (format t "SZS output end Proof~%")
+	      (format t "% SZS output end Proof~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
 	      )
 	    r)
 	(if (eq foo 'satisfiable)
-	    (progn
+	    (let ((r 10))
 	      (if *conjecture-given*
-		  (progn
-		    (format t "++ SUCCESS! CounterSatisfiable~%")
-		    10
-		    )
+		  (format t "% SZS status CounterSatisfiable~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
 		(progn
-		  (format t "++ SUCCESS! Satisfiable~%")
-		  15
-		  )))
+		  (format t "% SZS status Satisfiable~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
+		  (setq r 15)
+		  ))
+	      (when *print-final-proof-info* ; Decided to also print the 'proof' here -- a satisfiable set of clauses.  A satisfying assignment induces an evident set, which in turn induces a (finite) model - Chad, Jan 2010
+		(format t "% SZS output start Proof~%")
+		(format t "Clauses:~%")
+		(write-string *clauses*)
+		(format t "Atoms:~%")
+		(print-atom-atlas)
+		(format t "% SZS output end Proof~%")
+		)
+	      r
+	      )
 	  (if (eq foo 'thf-fail)
 	      (progn
-		(format t "-- FAILED! Error (THF Error)~%")
+		(unless *slave*
+		  (format t "% SZS status Error : (THF Error)~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
+		  )
 		2)
 	    (progn
-;	      (if foo
-;		  (format t "-- FAILED! Error ~d~%" foo)
-	      (format t "-- FAILED! Error~%")
-;		)
+	      (unless *slave*
+		(format t "% SZS status Error~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
+		)
 	      3)))))))
 
